@@ -51,7 +51,7 @@ def add_tautomers(
     to_exclude=[],
     terminal_offset=5000,
 ):
-    removed_pdb = prepare_for_addHtaut(
+    removed_pdb, resnumbered_res = prepare_for_addHtaut(
         pdb_in, pdb_prep, chains_res, to_exclude, terminal_offset=terminal_offset
     )
     sites_addHtaut = select_tautomer_sites(chains_res)
@@ -81,7 +81,7 @@ def add_tautomers(
                     e.stderr.decode("ascii")
                 )
             )
-    return removed_pdb
+    return removed_pdb, resnumbered_res
 
 
 def correct_names(resnumb, resname, aname, titrating_sites, termini):
@@ -146,7 +146,7 @@ def prepare_for_addHtaut(
     chains = sites.keys()
     ninsertions = -1
     inserted_block = None
-    already_inserted = []
+    renumbered_res = {}
     for line in content:
         if line.startswith("ATOM"):
             termini_trigger = False
@@ -186,13 +186,17 @@ def prepare_for_addHtaut(
                     new_res_trigger = True
 
                 inserted_block = insertion_code
-                resnumb += insertion_offset + ninsertions
+                resnumb_offset = insertion_offset + ninsertions
+                resnumb += resnumb_offset
 
                 if new_res_trigger:
-                    while resnumb in already_inserted:
+                    while resnumb in renumbered_res.keys():
                         resnumb += 1
-                    if resnumb not in already_inserted:
-                        already_inserted.append(resnumb)
+                    if resnumb not in renumbered_res.keys():
+                        renumbered_res[resnumb] = (
+                            resnumb - resnumb_offset,
+                            insertion_code,
+                        )
 
             new_line = new_pdb_line(
                 anumb,
@@ -230,7 +234,7 @@ def prepare_for_addHtaut(
 
     with open("removed.pqr", "w") as f_new:
         f_new.write(removed_pdb_text)
-    return removed_pdb_text
+    return removed_pdb_text, renumbered_res
 
 
 def get_cys_bridges(f_pdb2pqr_log):
